==> ssb-hyper-blobs-1.2.0.tgz: package/auto-prune.js <==
const pull = require('pull-stream')
const paraMap = require('pull-paramap')

const Prune = require('./prune')

const SEC = 1000
const MIN = 60 * SEC
const HOUR = 60 * MIN
const GB = 1024 * 1024 * 1024

module.exports = function autoPrune (artefactServer, ssb) {
  let config = (ssb.config.hyperBlobs && ssb.config.hyperBlobs.autoPrune)

  if (!config) return

  if (config === true) config = {}
  const {
    startDelay = 10 * MIN,
    intervalTime = HOUR,
    maxRemoteSize = 5 * GB
  } = config

  const prune = () => {
    runPrune(artefactServer, maxRemoteSize, (err, totalPruned) => {
      if (err) console.error('ssb-hyper-blobs: error occurred in auto-prune', err)
      else console.log(`ssb-hyper-blobs: auto-pruned ${totalPruned} bytes`)
    })
  }

  let interval

  ssb.close.hook((close, args) => {
    const _this = this

    clearInterval(interval)
    close.apply(_this, args)
  })

  setTimeout(
    () => {
      prune()
      interval = setInterval(prune, intervalTime)
    },
    startDelay
  )
}

let isPruning = false
function runPrune (artefactServer, maxRemoteSize, cb) {
  const prune = Prune(artefactServer)

  if (isPruning) return
  isPruning = true

  return pull(
    pullDriveSizes(artefactServer),
    pull.collect((err, sizes) => {
      if (err) return cb(err)

      const totalSize = sizes.reduce((a, b) => a + b, 0)
      const pruneSize = totalSize - maxRemoteSize

      if (pruneSize <= 0) {
        isPruning = false
        cb(null, 0)
        return
      }

      prune({ pruneSize }, (err, prunedFiles) => {
        isPruning = false

        if (err) {
          return cb(err)
        }

        const totalPruned = prunedFiles.reduce((acc, file) => acc + file.size, 0)

        cb(null, totalPruned)
      })
    })
  )
}

function pullDriveSizes (artefactServer) {
  return pull(
    pull.values(artefactServer.store.remoteDrives),
    pull.map(drive => drive.key),
    paraMap((driveAddress, cb) => {
      artefactServer.store.driveSize(driveAddress)
        .catch(err => cb(err))
        .then(size => cb(null, size))
    }, 6)
  )
}

==> ssb-hyper-blobs-2.1.0.tgz: package/auto-prune.js <==
const pull = require('pull-stream')
const paraMap = require('pull-paramap')

const Prune = require('./prune')

const SEC = 1000
const MIN = 60 * SEC
const HOUR = 60 * MIN
const GB = 1024 * 1024 * 1024

module.exports = function autoPrune (artefactServer, ssb) {
  let config = (ssb.config.hyperBlobs && ssb.config.hyperBlobs.autoPrune)

  if (!config) return

  if (config === true) config = {}
  const {
    startDelay = 10 * MIN,
    intervalTime = HOUR,
    maxRemoteSize = 5 * GB
  } = config

  const prune = () => {
    runPrune(artefactServer, maxRemoteSize, (err, totalPruned) => {
      if (err) console.error('ssb-hyper-blobs: error occurred in auto-prune', err)
      else console.log(`ssb-hyper-blobs: auto-pruned ${totalPruned} bytes`)
    })
  }

  let interval

  ssb.close.hook((close, args) => {
    const _this = this

    clearInterval(interval)
    close.apply(_this, args)
  })

  setTimeout(
    () => {
      prune()
      interval = setInterval(prune, intervalTime)
    },
    startDelay
  )
}

let isPruning = false
function runPrune (artefactServer, maxRemoteSize, cb) {
  const prune = Prune(artefactServer)

  if (isPruning) return cb(new Error('pruning already underway, skipping runPrune'))
  isPruning = true

  return pull(
    pullDriveSizes(artefactServer),
    pull.collect((err, sizes) => {
      if (err) return cb(err)

      const totalSize = sizes.reduce((a, b) => a + b, 0)
      const pruneSize = totalSize - maxRemoteSize

      if (pruneSize <= 0) {
        isPruning = false
        cb(null, 0)
        return
      }

      prune({ pruneSize }, (err, prunedFiles) => {
        isPruning = false

        if (err) {
          return cb(err)
        }

        const totalPruned = prunedFiles.reduce((acc, file) => acc + file.size, 0)

        cb(null, totalPruned)
      })
    })
  )
}

function pullDriveSizes (artefactServer) {
  return pull(
    pull.values(artefactServer.store.remoteDrives),
    pull.map(drive => drive.key),
    paraMap((driveAddress, cb) => {
      artefactServer.store.driveSize(driveAddress)
        .catch(err => cb(err))
        .then(size => cb(null, size))
    }, 6)
  )
}
